Inventariseren

# Leather & Tanning

This survey was offered to you by Leather Tanning.
Leather and Tanning: A Potentially High Risk Sector

As the tanner deals with heavy machines and various chemicals, the tanning industry among other industries belongs to the potentially higher risk sectors regarding health and safety at the workplace. Wrong handling of machines can cause severe damage to the human body and improper handling of chemicals can create health hazards to humans. An inappropriate working environment can also increase sick leave and reduce motivation and commitment of workers.

Goal of the risk assessment tool

Therefore the Social Partners of the European Leather Industry, industriAll and COTANCE have agreed to develop an online tool to support small and medium sized tanners in particular in the proper management of occupational health and safety risks. The tool is meant as a reference to give valuable information and suggestions to perform a risk assessment for the tannery in order to minimise and eliminate health and safety risks. Implementation of the tool does not however ensure legal compliance with the respective national health and safety regulations. It is intended to raise awareness of health and safety issues in the tannery and give examples for good practices.

The tool covers the following areas:

- OSH Management
- Building and floors
- In-house transport
- Emergency management - including fire risk
- Environmental conditions
- Working with raw hides and skins
- Use of knives
- Use of machines
- Maintenance, mounting and cleaning of machines
- Use of chemicals
- Office workplaces
- Organisational aspect

Employee involvement

It´s highly recommended to closely consult with the employees in the company when answering the questions. Employees are experts when it comes to answering questions on their working conditions. Employees can be consulted directly, e.g. you can print the content of the tool, go through the company and get input from the employees. Another option is to answer the questions together with an employee representative who - in the best case - has special knowledge on occupational safety and health.

How to use this tool

When using the tool, you are guided through the different steps:

The first page offers you the option to print the general content of the tool. This might make it easier for you, if you want to go through all the questions in the paper version - e.g. to take the print out to the shop floor.

When starting with the risk assessment, you will be guided through the modules listed above. Questions that are answered with "no" represent a risk and will be marked on the left hand menu with a red square. Questions that are answered with "yes" indicate that everything is correct with regard to the respective aspect. Accordingly a green dot will show up on the left hand menu. If you skip a question to answer later, an orange triangle will indicate that you still haven´t dealt with the respective question.

After assessing if certain risks are present, you will be guided automatically to the next step: the risk evaluation. You can also always choose to jump between the different steps by using the tags on the top of the page (assessment, evaluation, action plan, report).

Risk evaluation is required by EU law. All the risks identified as being present at the workplace will have to be evaluated according to three factors: probability, frequency and severity. The result of the evaluation with these three factors will determine whether the risk is low, medium or high priority. It may be the case that some risks have already been determined as a high priority by default (because the consequences of the risk occurring are highly severe). You will therefore not have to evaluate these risks.
Other risks may refer to certain policies in place in your company. They are either in place or not and therefore are not related to probability, frequency or severity. You will not have to evaluate these so called policy risks either.

The step following the risk evaluation is constructing an action plan. For those risks that were considered to be present, it is required to set up an action plan. When clicking through the different risks, you can choose standard solutions offered by the tool or you can enter your own ideas and solutions. In addition you can already appoint a responsible person to take care of the respective measure and you can add deadlines and estimates of the budget needed for taking action.

The last step is then getting your report. You can download your report in word format and edit it in whatever way you feel it´s necessary.

There are just four steps to get your risk management process started. Try the tool!

Previous

1. Preparation
2. Identification
3. Evaluation
4. Action Plan
5. Report

Produced by EU-OSHA. | About | Privacy | Disclaimer | GPL License |